/******************************************************************************
 * Password_Command - Client changes his password
 * $Id: Password_Command.java,v 1.4 2011/06/09 18:19:19 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Password_Command.java,v $
 * Revision 1.4  2011/06/09 18:19:19  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.3  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import java.util.StringTokenizer;

import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;

/** Client changes his password
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.4 $ <br> $Date: 2011/06/09 18:19:19 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Password_Command.java">cvs Password_Command.java</a>
 */
public class Password_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		String msg = null;

		if (args.length != 2) {
			// m_password_useage1=** usage: password <old password>:<new
			// password>:<new password>
			msg = jibsMessages.convert("m_password_useage1");
			player.println(msg);
			// m_password_useage2=** NOTE: The character between the passwords
			// is now a colon!
			msg = jibsMessages.convert("m_password_useage2");
			player.println(msg);

			return true;
		}

		String oldPassword = null;
		String newPassword1 = null;
		String newPassword2 = null;
		boolean useage = false;
		StringTokenizer token = new StringTokenizer(args[1], ":");

		if (token.hasMoreElements()) {
			oldPassword = token.nextToken();

			if (token.hasMoreElements()) {
				newPassword1 = token.nextToken();

				if (token.hasMoreElements()) {
					newPassword2 = token.nextToken();
					useage = true;
				}
			}
		}

		if (!useage) {
			// m_password_useage1=** usage: password <old password>:<new
			// password>:<new password>
			msg = jibsMessages.convert("m_password_useage1");
			player.println(msg);
			// m_password_useage2=** NOTE: The character between the passwords
			// is now a colon!
			msg = jibsMessages.convert("m_password_useage2");
			player.println(msg);

			return true;
		}

		// useage is ok are the parameters?
		if (!player.getPassword().equals(oldPassword)) {
			// m_password_badpassword1=** Sorry. Old password not correct.
			msg = jibsMessages.convert("m_password_badpassword1");
			player.println(msg);

			return true;
		}

		if (!newPassword1.equals(newPassword2)) {
			// m_password_badpassword2=** Please give your new password twice.
			msg = jibsMessages.convert("m_password_badpassword2");
			player.println(msg);

			return true;
		}

		// Everything ok to change the password
		player.changePassword(newPassword1);
		// m_password_change=Password changed.
		msg = jibsMessages.convert("m_password_change");
		player.println(msg);

		return true;
	}
}
