/******************************************************************************
 * SavedGameParam - Pojo of saved game data.
 * $Id: SavedGameParam.java,v 1.2 2011/05/31 15:25:49 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: SavedGameParam.java,v $
 * Revision 1.2  2011/05/31 15:25:49  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.util;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.backgammon.JibsMatch;
import net.sourceforge.jibs.server.Player;

import java.util.Date;

/** Pojo of saved game data. 
 * 
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.2 $ <br> $Date: 2011/05/31 15:25:49 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/util/SavedGameParam.java">cvs SavedGameParam.java</a>
 */
public class SavedGameParam {
	private Long id;
	private String player_A;
	private String player_B;
	private Date savedDate;
	private String board;
	private Integer matchlength;
	private Integer turn;
	private Integer matchVersion;
	private Player player1;
	private Player player2;

	public SavedGameParam() {
	}

	public SavedGameParam(String name1, String name2) {
		this.player_A = name1;
		this.player_B = name2;
	}

	public SavedGameParam(JibsGame game, Player playerX, Player playerO,
			BackgammonBoard backgammonBoard, int matchlength2,
			int turn2, JibsMatch matchVersion2, Date date) {
		this.player1 = playerX;
		this.player2 = playerO;
		this.player_A = playerX.getName();
		this.player_B = playerO.getName();
		this.savedDate = date;
		this.board = backgammonBoard.getOutputBoard(game);
		this.matchlength = matchlength2;
		this.turn = turn2;
		this.matchVersion = matchVersion2.getVersion();
	}

	public Date getSavedDate() {
		return savedDate;
	}

	public void setSavedDate(Date savedDate) {
		this.savedDate = savedDate;
	}

	public Integer getTurn() {
		return turn;
	}

	public void setTurn(Integer turn) {
		this.turn = turn;
	}

	public Integer getMatchlength() {
		return matchlength;
	}

	public void setMatchlength(Integer matchlength) {
		this.matchlength = matchlength;
	}

	public Integer getMatchVersion() {
		return matchVersion;
	}

	public void setMatchVersion(Integer matchVersion) {
		this.matchVersion = matchVersion;
	}

	public String getBoard() {
		return board;
	}

	public void setBoard(String board) {
		this.board = board;
	}

	public String getPlayer_A() {
		return player_A;
	}

	public void setPlayer_A(String playerA) {
		this.player_A = playerA;
	}

	public String getPlayer_B() {
		return player_B;
	}

	public void setPlayer_B(String playerB) {
		this.player_B = playerB;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Player getPlayer1() {
		return player1;
	}

	public Player getPlayer2() {
		return player2;
	}

	public void setPlayer1(Player player) {
		this.player1 = player;
	}

	public void setPlayer2(Player player) {
		this.player2 = player;
	}

	public Player getPlayerX() {
		if (player_A.equalsIgnoreCase(player1.getName())) {
			return player1;
		}

		if (player_A.equalsIgnoreCase(player2.getName())) {
			return player2;
		}

		return null;
	}

	public Player getPlayerO() {
		if (player_B.equalsIgnoreCase(player2.getName())) {
			return player2;
		}

		if (player_B.equalsIgnoreCase(player1.getName())) {
			return player1;
		}

		return null;
	}
}
